@@ -1,3 +1,4 @@
+import sys
 import datetime
 from typing import Union, List
 from serial_json.interface import register
@@ -34,6 +35,12 @@ DATETIME_FORMATS.extend([d + ' ' + t for t in TIME_FORMATS[1:] for d in DATE_FOR
 DATETIME_FORMATS.extend(DATE_FORMATS[1:])
 DATETIME_FORMATS.extend(TIME_FORMATS[1:])
 
+# Fallback iso parsing
+if sys.version_info < (3, 7):
+    # DATE_FORMATS.extend(['%Y-%m-%d'])  # Already being parsed
+    # TIME_FORMATS.extend(['%H:%M:%S.%f'])
+    DATETIME_FORMATS.extend(['%Y-%m-%dT%H:%M:%S.%f', '%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'])
+
 
 def make_date(date_string, formats=None):
     """Make the date object from the given time string.
@@ -112,7 +119,7 @@ def make_datetime(date_string, formats=None):
     for fmt in formats:
         try:
             if str(fmt).upper() == 'ISO':
-                return datetime.datetime.fromisoformat(date_string)
+                return datetime.datetime.fromisoformat(date_string)  # ... Added in Python 3.7
             else:
                 return datetime.datetime.strptime(date_string, fmt)
         except (TypeError, ValueError, Exception):
